ALBERT, BERT, ROBERTA and other language models fine tuned for the open domain question answering problem (SQUAD, etc)

- models for QABot are downloaded from Digital Ocean spaces and decompressed here
